@@ -22,6 +22,7 @@ class Client(metaclass=abc.ABCMeta):
         return ImmutableDTO.fromdict(await response.json())
 
     async def request(self, fn, *args, **kwargs):
+        allow_failure = kwargs.pop('allow_failure', False)
         retry = kwargs.pop('retry', False)
         deserialize = kwargs.pop('deserialize', True)
         kwargs.setdefault('ssl', settings.ENABLE_SSL)
@@ -38,7 +39,8 @@ class Client(metaclass=abc.ABCMeta):
             kwargs['retry'] = True
             await self.refresh_credentials()
             return await self.request(fn, *args, **kwargs)
-        response.raise_for_status()
+        if not allow_failure:
+            response.raise_for_status()
         if deserialize:
             response = await self.fromjson(response)
         return response
@@ -47,6 +49,10 @@ class Client(metaclass=abc.ABCMeta):
         return await self.request(self.session.get, *args, **kwargs)
 
     async def head(self, *args, **kwargs):
+        kwargs.update({
+            'deserialize': False,
+            'allow_failure': True
+        })
         return await self.request(self.session.head, *args, **kwargs)
 
     async def patch(self, *args, **kwargs):
